aboutsummaryrefslogtreecommitdiffstats
path: root/examples/axcontainer/axviewer.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/axcontainer/axviewer.py')
-rw-r--r--examples/axcontainer/axviewer.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/examples/axcontainer/axviewer.py b/examples/axcontainer/axviewer.py
index 50e50ee1c..2bd32ef0b 100644
--- a/examples/axcontainer/axviewer.py
+++ b/examples/axcontainer/axviewer.py
@@ -39,12 +39,12 @@
##
#############################################################################
"""PySide2 Active Qt Viewer example"""
import sys
-from PySide2.QtAxContainer import QAxSelect, QAxWidget
-from PySide2.QtGui import QAction
-from PySide2.QtWidgets import (QApplication, QDialog,
+from PySide6.QtAxContainer import QAxSelect, QAxWidget
+from PySide6.QtGui import QAction
+from PySide6.QtWidgets import (QApplication, QDialog,
QMainWindow, QMessageBox, QToolBar)
class MainWindow(QMainWindow):
@@ -39,12 +39,12 @@
##
#############################################################################
-"""PySide2 Active Qt Viewer example"""
+"""PySide6 Active Qt Viewer example"""
import sys